@@ -32,8 +32,8 @@ class VncHostPreferences : public HostPreferences
     Q_OBJECT
 
 public:
-    explicit VncHostPreferences(KConfigGroup configGroup, QObject *parent = 0);
-    ~VncHostPreferences();
+    explicit VncHostPreferences(KConfigGroup configGroup, QObject *parent = nullptr);
+    ~VncHostPreferences() override;
 
     void setQuality(RemoteView::Quality quality);
     RemoteView::Quality quality();
